@@ -1,10 +1,10 @@
-from typing import List, Union
+import datetime
+from typing import List
 import requests, json
 from ddd_objects.infrastructure.ao import exception_class_dec
-from ddd_objects.infrastructure.repository_impl import error_factory
 from ddd_objects.domain.exception import return_codes
 from ddd_objects.lib import Logger as _Logger
-from .do import LogRecordDO
+from .do import LogItemDO, LogRecordDO
 
 logger = _Logger()
 logger.set_labels(file_name=__file__)
@@ -28,31 +28,50 @@ class LogController:
                 f'error info: {error_info}')
 
     @exception_class_dec(max_try=1)
-    def add_record(self, record: LogRecordDO, timeout=30):
-        try:
-            data = json.dumps(record.to_json())
-            response=requests.post(f'{self.url}/record', data=data, timeout=timeout)
-            info = json.loads(response.text)
-            self._check_error(response.status_code, info)
-            return True
-        except:
-            logger.error(f'Error detected by log-control-ao when connecting to log collector')
-            return False
+    def add_record(self, record: LogRecordDO, timeout=3):
+        data = json.dumps(record.dict())
+        response=requests.post(f'{self.url}/record', data=data, timeout=timeout)
+        succeed = json.loads(response.text)
+        print(succeed)
+        self._check_error(response.status_code, succeed)
+        return succeed
+
+    @exception_class_dec(max_try=1)
+    def find_unprocessed_items(self, timeout=3):
+        response=requests.get(f'{self.url}/unprocessed_items', timeout=timeout)
+        items = json.loads(response.text)
+        self._check_error(response.status_code, items)
+        if items is None:
+            return None
+        else:
+            return [LogItemDO(**m) for m in items]
+
+    @exception_class_dec(max_try=1)
+    def update_items_processed(self, items:List[LogItemDO], timeout=3):
+        data = json.dumps([m.dict() for m in items])
+        response=requests.post(f'{self.url}/items/processed', data=data, timeout=timeout)
+        succeed = json.loads(response.text)
+        self._check_error(response.status_code, succeed)
+        return succeed
 
 class Logger:
     def __init__(
-        self, domain, location, labels=None, life_time=None,
-        controller_ip=None, controller_port=None, local:bool=False
+        self, 
+        domain, 
+        location, 
+        labels=None,
+        keywords=[],
+        controller_ip=None, 
+        controller_port=None, 
+        local:bool=False
     ) -> None:
         self.domain = domain
         self.location = location
         if labels is None:
             labels = ['default']
-        if life_time is None:
-            life_time = 600
         self.labels = labels
-        self.life_time =life_time
         self.local = local
+        self.keywords = keywords
         self.controller = LogController(controller_ip, controller_port)
 
     def _send_record(
@@ -62,8 +81,7 @@ class Logger:
         domain=None, 
         location=None, 
         labels=None, 
-        life_time=None,
-        datetime = None
+        keywords=None
     ):
         if domain is None:
             domain = self.domain
@@ -71,18 +89,24 @@ class Logger:
             location = self.location
         if labels is None:
             labels = self.labels
-        if life_time is None:
-            life_time = self.life_time
+        if keywords is None:
+            keywords = self.keywords
         record = LogRecordDO(
             log_type = record_type,
             log_domain = domain,
             log_location = location,
             log_inhalt = content,
             log_label = labels,
-            log_datetime = datetime,
-            _life_time = life_time
+            log_keywords = keywords,
+            creation_time = datetime.datetime.utcnow().isoformat()
         )
-        return self.controller.add_record(record)
+        print(record)
+        result = self.controller.add_record(record)
+        print(result.error_traceback)
+        if result.succeed:
+            return result.get_value()
+        else:
+            return False
 
     def info(
         self, 
@@ -90,12 +114,11 @@ class Logger:
         domain=None, 
         location=None, 
         labels=None, 
-        life_time=None,
-        datetime = None
+        keywords=None
     ):
         if self.local:
             logger.info(content)
-        return self._send_record(content, 'info', domain, location, labels, life_time, datetime)
+        return self._send_record(content, 'info', domain, location, labels, keywords)
 
     def error(
         self, 
@@ -103,10 +126,9 @@ class Logger:
         domain=None, 
         location=None, 
         labels=None, 
-        life_time=None,
-        datetime = None
+        keywords=None
     ):
         if self.local:
             logger.error(content)
-        return self._send_record(content, 'error', domain, location, labels, life_time, datetime)
+        return self._send_record(content, 'error', domain, location, labels, keywords)
 
